@@ -3,7 +3,9 @@
 from abc import ABC, abstractmethod
 from collections import namedtuple
 from datetime import datetime
-from typing import Any, Generator, Iterable, Optional
+from typing import Any, Generator, Iterable, Optional, Tuple
+
+from libratom.lib.constants import BodyType
 
 AttachmentMetadata = namedtuple("AttachmentMetadata", ["name", "mime_type", "size"])
 
@@ -43,6 +45,16 @@ class Archive(ABC):  # pragma: no cover
     def format_message(message: Any, with_headers: bool) -> str:
         ...
 
+    @staticmethod
+    @abstractmethod
+    def get_message_body(message: Any) -> Tuple[str, Optional[BodyType]]:
+        ...
+
+    @staticmethod
+    @abstractmethod
+    def get_message_headers(message: Any) -> Optional[str]:
+        ...
+
     @staticmethod
     @abstractmethod
     def get_message_date(message: Any) -> datetime:
